#!/bin/sh
# test.sh -- run hysep test data sets
#
# Usage: test.sh [start [stop]]
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# History: 96/03/05  kmflynn
#          98/01/23

# pathname
WrdA=/usr/opt/wrdapp
Prgm=$WrdA/hysep2.2

#*******************************************************************
#***** You should not need to modify anything below this line. *****
#*******************************************************************

# pathnames and other variables
  Data=$Prgm/data
  Chck=$Prgm/test

#
  exec 2>&1                           # stderr shows up in .out file
  Start=${1-1}                        # by default, start at 1
  Stop=${2-4}                         # by default, stop at 4
                                      # 1 - local minimum method
                                      # 2 - sliding interval method
                                      # 3 - fixed interval method
                                      # 4 - local minimum method
#
# begin test runs
  echo
  echo _________________________________________________________________
  echo " Processing hysep test runs $Start to $Stop"
  echo " hysep program from: $Prgm"
  echo "     test data from: $Data"
  echo `date`

# make sure latest input files present
  for Inp in french.gsd french.wdm ; do
    if [ -f $Inp ] ; then rm $Inp ; fi
    cp -p $Data/$Inp $Inp
  done

  Test=$Start
  while [ $Test -ge $Start -a $Test -le $Stop ] ; do
#   each requested test run
    echo
    echo
    echo _________________________________________________________________
    echo "Test run number $Test"
    echo
    for Fils in test$Test.prt test$Test.dpr test$Test.fpr test$Test.hpr ; do
#      remove old files
       if [ -f $Fils ] ; then rm $Fils ; fi
    done

    $Prgm/bin/hysep <<-EOT
	@$Data/test$Test.log
	EOT

#   remove unneeded files
    rm HYSEP.LOG ERROR.FIL

    Test=`expr $Test + 1`
  done

# remove unneeded input files
  for Inp in french.gsd french.wdm ; do
    rm $Inp
  done

#
  echo
  echo
  echo _________________________________________________________________
  echo "Completed HYSEP test runs $Start to $Stop"
  echo
# check output against original output in $Data directory
  $Chck/check.sh $Data

# end of shell
